@@ -1,3 +1,5 @@
+import os
+
 from pika import BlockingConnection
 
 
@@ -10,8 +12,10 @@ def create_exchange_and_bind_queue(
 ):
     queue_arguments = {}
     if dead_letter:
+        # Note: If queue is already created with another RABBITMQ_MESSAGE_TTL, it will fail.
+        message_ttl = int(os.environ.get("RABBITMQ_MESSAGE_TTL", "1000"))  # 1 second
         queue_arguments = {
-            "x-message-ttl": 1000,
+            "x-message-ttl": message_ttl,
             "x-dead-letter-exchange": f"dlx-{exchange}",
         }
 
